==> cpm-1.1.0.tar.gz: cpm-1.1.0/collectives/hockney_collectives.h <==
#ifndef HOCKNEY_COLLECTIVES_H_
#define HOCKNEY_COLLECTIVES_H_

#include "hockney.h"
#include "cpm_collectives.h"

/*!
 * \defgroup hockney_collectives Hockney-based collective operations
 * The implementations of tree-based algorithms are similar to \latexonly \cite{Hatta2000}
 * and \cite{Bhat2003} \endlatexonly.
 * \{
 */
#ifdef __cplusplus
extern "C" {
#endif

/*!
 * The global instance of Hockney model for use in the optimized scatter/gather.
 * Must be initialized by \ref Hockney_initialize and destroyed by \ref Hockney_finalize
 * at all processes. 
 */
extern Hockney_model* Hockney_model_instance;

/*!
 * Initializes the instances of the Hockney model (\ref Hockney_model_instance)
 * at all processes in the communicatior.
 * \param comm MPI communicator 
 * \param model Hockney model (significant only at root)
 */
int Hockney_initialize(MPI_Comm comm, Hockney_model* model);

/*!
 * Destroys the instances of the Hockney model (\ref Hockney_model_instance)
 * at all processes in the communicatior.
 */
int Hockney_finalize(MPI_Comm comm);

/*! Sorted flat-tree scatterv based on the Hockney model. */
int Hockney_Scatterv_sorted_flat_asc(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree gatherv based on the Hockney model. */
int Hockney_Gatherv_sorted_flat_asc(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree scatterv based on the Hockney model. */
int Hockney_Scatterv_sorted_flat_dsc(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree gatherv based on the Hockney model. */
int Hockney_Gatherv_sorted_flat_dsc(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

#ifdef HAVE_LIBBOOST_GRAPH

/*! DFS binomial bcast based on the Hockney model. */
int Hockney_Bcast_dfs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! DFS binomial reduce based on the Hockney model. */
int Hockney_Reduce_dfs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! DFS binomial bcast based on the Hockney model. */
int Hockney_Bcast_dfs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! BFS binomial reduce based on the Hockney model. */
int Hockney_Reduce_bfs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! BFS binomial reduce based on the Hockney model. */
int Hockney_Reduce_bfs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! BFS binomial bcast based on the Hockney model. */
int Hockney_Bcast_bfs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! BFS binomial bcast based on the Hockney model. */
int Hockney_Bcast_bfs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! DFS binomial reduce based on the Hockney model. */
int Hockney_Reduce_dfs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! UCS binomial bcast based on the Hockney model. */
int Hockney_Bcast_ucs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! UCS binomial reduce based on the Hockney model. */
int Hockney_Reduce_ucs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! UCS binomial bcast based on the Hockney model. */
int Hockney_Bcast_ucs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! UCS binomial reduce based on the Hockney model. */
int Hockney_Reduce_ucs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! DFS binomial scatter based on the Hockney model. */
int Hockney_Scatter_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gather based on the Hockney model. */
int Hockney_Gather_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatter based on the Hockney model. */
int Hockney_Scatter_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gather based on the Hockney model. */
int Hockney_Gather_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatter based on the Hockney model. */
int Hockney_Scatter_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gather based on the Hockney model. */
int Hockney_Gather_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatter based on the Hockney model. */
int Hockney_Scatter_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gather based on the Hockney model. */
int Hockney_Gather_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatter based on the Hockney model. */
int Hockney_Scatter_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gather based on the Hockney model. */
int Hockney_Gather_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatter based on the Hockney model. */
int Hockney_Scatter_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gather based on the Hockney model. */
int Hockney_Gather_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_dfs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_dfs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_bfs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_bfs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_ucs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_ucs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Scatterv based on modified Traff using the Hockney model. */
int Hockney_Scatterv_Traff(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Gatherv based on modified Traff using the Hockney model. */
int Hockney_Gatherv_Traff(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

#endif

#ifdef __cplusplus
}
#endif
/*!
 * \}
 */

#endif /*HOCKNEY_COLLECTIVES_H_*/

==> cpm-1.2.0.tar.gz: cpm-1.2.0/collectives/hockney_collectives.h <==
#ifndef HOCKNEY_COLLECTIVES_H_
#define HOCKNEY_COLLECTIVES_H_

#ifdef HAVE_CONFIG_H
#include "models/hockney.h"
#else
#include "hockney.h"
#endif

/*!
 * \defgroup hockney_collectives Hockney-based collective operations
 * The implementations of tree-based algorithms are similar to \latexonly \cite{Hatta2000}
 * and \cite{Bhat2003} \endlatexonly.
 * \{
 */
#ifdef __cplusplus
extern "C" {
#endif

/*!
 * Initializes the instances of the Hockney model at all processes in the communicatior.
 * \param comm MPI communicator 
 * \param model Hockney model (significant only at root)
 */
int Hockney_initialize(MPI_Comm comm, Hockney_model* model);

/*! Destroys the instances of the Hockney model at all processes in the communicatior. */
int Hockney_finalize(MPI_Comm comm);

/*! Sorted flat-tree scatterv based on the Hockney model. */
int Hockney_Scatterv_sorted_flat_asc(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree gatherv based on the Hockney model. */
int Hockney_Gatherv_sorted_flat_asc(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree scatterv based on the Hockney model. */
int Hockney_Scatterv_sorted_flat_dsc(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Sorted flat-tree gatherv based on the Hockney model. */
int Hockney_Gatherv_sorted_flat_dsc(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial bcast based on the Hockney model. */
int Hockney_Bcast_dfs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! DFS binomial reduce based on the Hockney model. */
int Hockney_Reduce_dfs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! DFS binomial bcast based on the Hockney model. */
int Hockney_Bcast_dfs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! BFS binomial reduce based on the Hockney model. */
int Hockney_Reduce_bfs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! BFS binomial reduce based on the Hockney model. */
int Hockney_Reduce_bfs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! BFS binomial bcast based on the Hockney model. */
int Hockney_Bcast_bfs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! BFS binomial bcast based on the Hockney model. */
int Hockney_Bcast_bfs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! DFS binomial reduce based on the Hockney model. */
int Hockney_Reduce_dfs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! UCS binomial bcast based on the Hockney model. */
int Hockney_Bcast_ucs_binomial_min(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! UCS binomial reduce based on the Hockney model. */
int Hockney_Reduce_ucs_binomial_min(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! UCS binomial bcast based on the Hockney model. */
int Hockney_Bcast_ucs_binomial_max(void* buffer, int count, MPI_Datatype datatype, int root, MPI_Comm comm);

/*! UCS binomial reduce based on the Hockney model. */
int Hockney_Reduce_ucs_binomial_max(void* sendbuf, void* recvbuf, int count, MPI_Datatype datatype,
	MPI_Op op, int root, MPI_Comm comm);

/*! DFS binomial scatter based on the Hockney model. */
int Hockney_Scatter_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gather based on the Hockney model. */
int Hockney_Gather_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatter based on the Hockney model. */
int Hockney_Scatter_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gather based on the Hockney model. */
int Hockney_Gather_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatter based on the Hockney model. */
int Hockney_Scatter_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gather based on the Hockney model. */
int Hockney_Gather_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatter based on the Hockney model. */
int Hockney_Scatter_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gather based on the Hockney model. */
int Hockney_Gather_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatter based on the Hockney model. */
int Hockney_Scatter_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gather based on the Hockney model. */
int Hockney_Gather_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatter based on the Hockney model. */
int Hockney_Scatter_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gather based on the Hockney model. */
int Hockney_Gather_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_dfs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_dfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_dfs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! DFS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_dfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_bfs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_bfs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_bfs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! BFS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_bfs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_ucs_binomial_min(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_ucs_binomial_min(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial scatterv based on the Hockney model. */
int Hockney_Scatterv_ucs_binomial_max(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! UCS binomial gatherv based on the Hockney model. */
int Hockney_Gatherv_ucs_binomial_max(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Scatterv based on modified Traff using the Hockney model. */
int Hockney_Scatterv_Traff(void* sendbuf, int* sendcounts, int* displs, MPI_Datatype sendtype,
	void* recvbuf, int recvcount, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

/*! Gatherv based on modified Traff using the Hockney model. */
int Hockney_Gatherv_Traff(void* sendbuf, int sendcount, MPI_Datatype sendtype,
	void* recvbuf, int* recvcounts, int* displs, MPI_Datatype recvtype,
	int root, MPI_Comm comm);

#ifdef __cplusplus
}
#endif
/*!
 * \}
 */

#endif /*HOCKNEY_COLLECTIVES_H_*/
